const path = require('path')
const webpack = require('webpack')
// const HappyPack = require('happypack')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const CopyWebpackPlugin = require('copy-webpack-plugin')
const { projectPath, resolve } = require('../utils')
const appConfig = require('../utils/get-app-config')
const vueOptions = require('./vue-loader.conf')
const styleOptions = require('./style-loader')

const config = {
  ...appConfig.webpack,
  mode: 'none',
  devtool: '#eval-source-map',
  output: {
    filename: '[name].js',
    path: `${projectPath}/public`,
  },
  module: {
    rules: [
      // {
      //   test: /\.jsx?$/,
      //   loader: 'happypack/loader',
      //   include: path.resolve(process.cwd(), 'client'),
      // },
      {
        test: /\.vue$/,
        loader: 'vue-loader',
        include: resolve('client'),
        options: vueOptions,
      },
      {
        test: /\.css$/,
        loader: styleOptions.cssLoader({}).css,
        include: [resolve('client'), resolve('node_modules/normalize.css')],
      },
      {
        test: /\.styl$/,
        loader: styleOptions.cssLoader({}).stylus,
        include: [resolve('client'), resolve('node_modules/normalize.css')],
      },
      {
        test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
        loaders: [
          {
            loader: 'url-loader',
            options: {
              limit: 8192,
              name: '[name].[ext]?[hash]',
            },
          },
        ],
      },
    ],
  },
  resolve: {
    alias: {
      'vue$': 'vue/dist/vue.esm.js',
      '@': resolve('client'),
    }
  },
  plugins: [
    new HtmlWebpackPlugin({
      filename: 'index.html',
      template: path.join(projectPath, 'index.template.ejs'),
      inject: true,
    }),
    new webpack.DllReferencePlugin({
      manifest: require(`${projectPath}/vendor_manifest.json`)
    }),
    new CopyWebpackPlugin([
      {
        from: `${projectPath}/static`,
        to: 'static',
      },
    ]),
    // new HappyPack({
    //   threads: 4,
    //   loaders: ['babel-loader?presets[]=es2015'],
    // }),
  ],
}

module.exports = config